@@ -8,9 +8,8 @@
 import re
 import shlex
 
-from gi.repository import GObject
-
 from quodlibet import const
+from quodlibet.util import print_d, print_w
 from .tcpserver import BaseTCPServer, BaseTCPConnection
 
 
@@ -29,6 +28,19 @@ class AckError(object):
     EXIST = 56
 
 
+class Permissions(object):
+    PERMISSION_NONE = 0
+    PERMISSION_READ = 1
+    PERMISSION_ADD = 2
+    PERMISSION_CONTROL = 4
+    PERMISSION_ADMIN = 8
+    PERMISSION_ALL = PERMISSION_NONE | \
+                     PERMISSION_READ | \
+                     PERMISSION_ADD | \
+                     PERMISSION_CONTROL | \
+                     PERMISSION_ADMIN
+
+
 TAG_MAPPING = [
     (u"Artist", "artist"),
     (u"ArtistSort", "artistsort"),
@@ -117,81 +129,32 @@ def parse_command(line):
     return command, dec_args
 
 
-class PlayerOptions(GObject.Object):
-    """Provides a simplified interface for playback options.
-
-    This should probably go into the core.
-    """
-
-    __gsignals__ = {
-        'random-changed': (GObject.SignalFlags.RUN_LAST, None, tuple()),
-        'repeat-changed': (GObject.SignalFlags.RUN_LAST, None, tuple()),
-        'single-changed': (GObject.SignalFlags.RUN_LAST, None, tuple()),
-    }
-
-    def __init__(self, app):
-        super(PlayerOptions, self).__init__()
-
-        self._repeat = app.window.repeat
-        self._rid = self._repeat.connect(
-            "toggled", lambda *x: self.emit("repeat-changed"))
-
-        def order_changed(*args):
-            self.emit("random-changed")
-            self.emit("single-changed")
-
-        self._order = app.window.order
-        self._oid = self._order.connect("changed", order_changed)
-
-    def destroy(self):
-        self._repeat.disconnect(self._rid)
-        del self._repeat
-        self._order.disconnect(self._oid)
-        del self._order
-
-    def set_single(self, value):
-        is_single = self.get_single()
-        if value and not is_single:
-            self._order.set_active_by_name("onesong")
-        elif not value and is_single:
-            self._order.set_active_by_name("inorder")
-
-    def get_single(self):
-        return self._order.get_active_name() == "onesong"
-
-    def get_random(self):
-        return self._order.get_shuffle()
-
-    def set_random(self, value):
-        self._order.set_shuffle(value)
-
-    def get_repeat(self):
-        return self._repeat.get_active()
-
-    def set_repeat(self, value):
-        self._repeat.set_active(value)
-
-
 class MPDService(object):
     """This is the actual shared MPD service which the clients talk to"""
 
     version = (0, 17, 0)
 
-    def __init__(self, app):
+    def __init__(self, app, config):
         self._app = app
         self._connections = set()
         self._idle_subscriptions = {}
         self._idle_queue = {}
         self._pl_ver = 0
 
-        self._options = PlayerOptions(app)
+        self._config = config
+        self._options = app.player_options
+
+        if not self._config.config_get("password"):
+            self.default_permission = Permissions.PERMISSION_ALL
+        else:
+            self.default_permission = Permissions.PERMISSION_NONE
 
         def options_changed(*args):
             self.emit_changed("options")
 
-        self._options.connect("random-changed", options_changed)
-        self._options.connect("repeat-changed", options_changed)
-        self._options.connect("single-changed", options_changed)
+        self._options.connect("notify::random", options_changed)
+        self._options.connect("notify::repeat", options_changed)
+        self._options.connect("notify::single", options_changed)
 
         self._player_sigs = []
 
@@ -227,9 +190,8 @@ class MPDService(object):
     def destroy(self):
         for id_ in self._player_sigs:
             self._app.player.disconnect(id_)
-        self._options.destroy()
-        del self._app
         del self._options
+        del self._app
 
     def add_connection(self, connection):
         self._connections.add(connection)
@@ -322,13 +284,13 @@ class MPDService(object):
         self._app.player.volume = (value / 100.0) ** 3.0
 
     def repeat(self, value):
-        self._options.set_repeat(value)
+        self._options.repeat = value
 
     def random(self, value):
-        self._options.set_random(value)
+        self._options.random = value
 
     def single(self, value):
-        self._options.set_single(value)
+        self._options.single = value
 
     def stats(self):
         has_song = int(bool(self._app.player.info))
@@ -358,9 +320,9 @@ class MPDService(object):
 
         status = [
             ("volume", int((app.player.volume ** (1.0 / 3.0)) * 100)),
-            ("repeat", int(self._options.get_repeat())),
-            ("random", int(self._options.get_random())),
-            ("single", int(self._options.get_single())),
+            ("repeat", int(self._options.repeat)),
+            ("random", int(self._options.random)),
+            ("single", int(self._options.single)),
             ("consume", 0),
             ("playlist", self._pl_ver),
             ("playlistlength", int(bool(app.player.info))),
@@ -424,13 +386,14 @@ class MPDService(object):
 
 class MPDServer(BaseTCPServer):
 
-    def __init__(self, app, port):
+    def __init__(self, app, config, port):
         self._app = app
+        self._config = config
         super(MPDServer, self).__init__(port, MPDConnection, const.DEBUG)
 
     def handle_init(self):
         print_d("Creating the MPD service")
-        self.service = MPDService(self._app)
+        self.service = MPDService(self._app, self._config)
 
     def handle_idle(self):
         print_d("Destroying the MPD service")
@@ -470,6 +433,8 @@ class MPDConnection(BaseTCPConnection):
         self._command = None
         # end - command processing state
 
+        self.permission = self.service.default_permission
+
         self.start_write()
         self.start_read()
 
@@ -511,6 +476,13 @@ class MPDConnection(BaseTCPConnection):
 
     #  ------------ rest ------------
 
+    def authenticate(self, password):
+        if password == self.service._config.config_get("password"):
+            self.permission = Permissions.PERMISSION_ALL
+        else:
+            self.permission = self.service.default_permission
+            raise MPDRequestError("Password incorrect", AckError.PASSWORD)
+
     def log(self, msg):
         if const.DEBUG:
             print_d("[%s] %s" % (self.name, msg))
@@ -549,7 +521,7 @@ class MPDConnection(BaseTCPConnection):
         if index is not None:
             error.append(u"@%d" % index)
         assert self._command is not None
-        error.append("u] {%s}" % self._command)
+        error.append(u"] {%s}" % self._command)
         if msg is not None:
             error.append(u" %s" % msg)
         self.write_line(u"".join(error))
@@ -602,7 +574,11 @@ class MPDConnection(BaseTCPConnection):
                 self.write_line(u"list_OK")
             return
 
-        cmd, do_ack = self._commands[command]
+        cmd, do_ack, permission = self._commands[command]
+        if permission != (self.permission & permission):
+            raise MPDRequestError("Insufficient permission",
+                    AckError.PERMISSION)
+
         cmd(self, self.service, args)
 
         if self._use_command_list:
@@ -614,11 +590,11 @@ class MPDConnection(BaseTCPConnection):
     _commands = {}
 
     @classmethod
-    def Command(cls, name, ack=True):
+    def Command(cls, name, ack=True, permission=Permissions.PERMISSION_ADMIN):
 
         def wrap(func):
             assert name not in cls._commands, name
-            cls._commands[name] = (func, ack)
+            cls._commands[name] = (func, ack, permission)
             return func
 
         return wrap
@@ -672,17 +648,24 @@ def _cmd_idle(conn, service, args):
     service.register_idle(conn, args)
 
 
-@MPDConnection.Command("ping")
+@MPDConnection.Command("ping", permission=Permissions.PERMISSION_NONE)
 def _cmd_ping(conn, service, args):
     return
 
 
+@MPDConnection.Command("password", permission=Permissions.PERMISSION_NONE)
+def _cmd_password(conn, service, args):
+    _verify_length(args, 1)
+    conn.authenticate(args[0])
+
+
 @MPDConnection.Command("noidle")
 def _cmd_noidle(conn, service, args):
     service.unregister_idle(conn)
 
 
-@MPDConnection.Command("close", ack=False)
+@MPDConnection.Command("close", ack=False,
+        permission=Permissions.PERMISSION_NONE)
 def _cmd_close(conn, service, args):
     conn.close()
 
@@ -851,7 +834,7 @@ def _cmd_outputs(conn, service, args):
     conn.write_line(u"outputenabled: 1")
 
 
-@MPDConnection.Command("commands")
+@MPDConnection.Command("commands", permission=Permissions.PERMISSION_NONE)
 def _cmd_commands(conn, service, args):
     for name in conn.list_commands():
         conn.write_line(u"command: " + unicode(name))
