@@ -7,14 +7,6 @@
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 2
 # as published by the Free Software Foundation.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You can get a copy of the GNU General Public License at:
-# http://www.gnu.org/licenses/gpl-2.0.html
 
 from gi.repository import Gtk, Gdk
 
@@ -71,6 +63,7 @@ class ViewLyrics(EventPlugin):
         If there are lyrics associated with `song`, load them into the
         lyrics viewer. Otherwise, hides the lyrics viewer.
         """
+        lyrics = None
         if song is not None:
             lyrics = song("~lyrics")
             if lyrics:
