@@ -8,7 +8,7 @@
 import os
 
 from quodlibet.util.path import fsnative, is_fsnative
-from quodlibet.util.uri import URI
+from quodlibet.compat import text_type
 
 from ._audio import AudioFile
 
@@ -23,8 +23,8 @@ class RemoteFile(AudioFile):
     format = "Remote File"
 
     def __init__(self, uri):
-        self["~uri"] = str(URI(uri))
-        self.sanitize(fsnative(unicode(self["~uri"])))
+        self["~uri"] = text_type(uri)
+        self.sanitize(fsnative(self["~uri"]))
 
     def __getitem__(self, key):
         # we used to save them with the wrong type
@@ -53,7 +53,7 @@ class RemoteFile(AudioFile):
         return True
 
     def write(self):
-        raise TypeError("RemoteFiles do not support writing!")
+        pass
 
     def can_change(self, k=None):
         if k is None:
@@ -65,5 +65,5 @@ class RemoteFile(AudioFile):
     def key(self):
         return self["~uri"]
 
-info = RemoteFile
+loader = RemoteFile
 types = [RemoteFile]
